---
title: The Bean-Field
id: the-bean-field
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 7
kind: article
---

## The Bean-Field

Meanwhile my beans, the length of whose rows, added together, was seven
miles already planted, were impatient to be hoed, for the earliest had
grown considerably before the latest were in the ground; indeed they
were not easily to be put off. What was the meaning of this so steady
and self-respecting, this small Herculean labor, I knew not. I came to
love my rows, my beans, though so many more than I wanted. They
attached me to the earth, and so I got strength like Antæus. But why
should I raise them? Only Heaven knows. This was my curious labor all
summer,—to make this portion of the earth’s surface, which had yielded
only cinquefoil, blackberries, johnswort, and the like, before, sweet
wild fruits and pleasant flowers, produce instead this pulse. What
shall I learn of beans or beans of me? I cherish them, I hoe them,
early and late I have an eye to them; and this is my day’s work. It is
a fine broad leaf to look on. My auxiliaries are the dews and rains
which water this dry soil, and what fertility is in the soil itself,
which for the most part is lean and effete. My enemies are worms, cool
days, and most of all woodchucks. The last have nibbled for me a
quarter of an acre clean. But what right had I to oust johnswort and
the rest, and break up their ancient herb garden? Soon, however, the
remaining beans will be too tough for them, and go forward to meet new
foes.

When I was four years old, as I well remember, I was brought from
Boston to this my native town, through these very woods and this field,
to the pond. It is one of the oldest scenes stamped on my memory. And
now to-night my flute has waked the echoes over that very water. The
pines still stand here older than I; or, if some have fallen, I have
cooked my supper with their stumps, and a new growth is rising all
around, preparing another aspect for new infant eyes. Almost the same
johnswort springs from the same perennial root in this pasture, and
even I have at length helped to clothe that fabulous landscape of my
infant dreams, and one of the results of my presence and influence is
seen in these bean leaves, corn blades, and potato vines.

I planted about two acres and a half of upland; and as it was only
about fifteen years since the land was cleared, and I myself had got
out two or three cords of stumps, I did not give it any manure; but in
the course of the summer it appeared by the arrowheads which I turned
up in hoeing, that an extinct nation had anciently dwelt here and
planted corn and beans ere white men came to clear the land, and so, to
some extent, had exhausted the soil for this very crop.

Before yet any woodchuck or squirrel had run across the road, or the
sun had got above the shrub oaks, while all the dew was on, though the
farmers warned me against it,—I would advise you to do all your work if
possible while the dew is on,—I began to level the ranks of haughty
weeds in my bean-field and throw dust upon their heads. Early in the
morning I worked barefooted, dabbling like a plastic artist in the dewy
and crumbling sand, but later in the day the sun blistered my feet.
There the sun lighted me to hoe beans, pacing slowly backward and
forward over that yellow gravelly upland, between the long green rows,
fifteen rods, the one end terminating in a shrub oak copse where I
could rest in the shade, the other in a blackberry field where the
green berries deepened their tints by the time I had made another bout.
Removing the weeds, putting fresh soil about the bean stems, and
encouraging this weed which I had sown, making the yellow soil express
its summer thought in bean leaves and blossoms rather than in wormwood
and piper and millet grass, making the earth say beans instead of
grass,—this was my daily work. As I had little aid from horses or
cattle, or hired men or boys, or improved implements of husbandry, I
was much slower, and became much more intimate with my beans than
usual. But labor of the hands, even when pursued to the verge of
drudgery, is perhaps never the worst form of idleness. It has a
constant and imperishable moral, and to the scholar it yields a classic
result. A very _agricola laboriosus_ was I to travellers bound westward
through Lincoln and Wayland to nobody knows where; they sitting at
their ease in gigs, with elbows on knees, and reins loosely hanging in
festoons; I the home-staying, laborious native of the soil. But soon my
homestead was out of their sight and thought. It was the only open and
cultivated field for a great distance on either side of the road; so
they made the most of it; and sometimes the man in the field heard more
of travellers’ gossip and comment than was meant for his ear: “Beans so
late! peas so late!”—for I continued to plant when others had begun to
hoe,—the ministerial husbandman had not suspected it. “Corn, my boy,
for fodder; corn for fodder.” “Does he _live_ there?” asks the black
bonnet of the gray coat; and the hard-featured farmer reins up his
grateful dobbin to inquire what you are doing where he sees no manure
in the furrow, and recommends a little chip dirt, or any little waste
stuff, or it may be ashes or plaster. But here were two acres and a
half of furrows, and only a hoe for cart and two hands to draw
it,—there being an aversion to other carts and horses,—and chip dirt
far away. Fellow-travellers as they rattled by compared it aloud with
the fields which they had passed, so that I came to know how I stood in
the agricultural world. This was one field not in Mr. Coleman’s report.
And, by the way, who estimates the value of the crop which nature
yields in the still wilder fields unimproved by man? The crop of
_English_ hay is carefully weighed, the moisture calculated, the
silicates and the potash; but in all dells and pond holes in the woods
and pastures and swamps grows a rich and various crop only unreaped by
man. Mine was, as it were, the connecting link between wild and
cultivated fields; as some states are civilized, and others
half-civilized, and others savage or barbarous, so my field was, though
not in a bad sense, a half-cultivated field. They were beans cheerfully
returning to their wild and primitive state that I cultivated, and my
hoe played the _Ranz des Vaches_ for them.

Near at hand, upon the topmost spray of a birch, sings the
brown-thrasher—or red mavis, as some love to call him—all the morning,
glad of your society, that would find out another farmer’s field if
yours were not here. While you are planting the seed, he cries,—“Drop
it, drop it,—cover it up, cover it up,—pull it up, pull it up, pull it
up.” But this was not corn, and so it was safe from such enemies as he.
You may wonder what his rigmarole, his amateur Paganini performances on
one string or on twenty, have to do with your planting, and yet prefer
it to leached ashes or plaster. It was a cheap sort of top dressing in
which I had entire faith.

As I drew a still fresher soil about the rows with my hoe, I disturbed
the ashes of unchronicled nations who in primeval years lived under
these heavens, and their small implements of war and hunting were
brought to the light of this modern day. They lay mingled with other
natural stones, some of which bore the marks of having been burned by
Indian fires, and some by the sun, and also bits of pottery and glass
brought hither by the recent cultivators of the soil. When my hoe
tinkled against the stones, that music echoed to the woods and the sky,
and was an accompaniment to my labor which yielded an instant and
immeasurable crop. It was no longer beans that I hoed, nor I that hoed
beans; and I remembered with as much pity as pride, if I remembered at
all, my acquaintances who had gone to the city to attend the oratorios.
The night-hawk circled overhead in the sunny afternoons—for I sometimes
made a day of it—like a mote in the eye, or in heaven’s eye, falling
from time to time with a swoop and a sound as if the heavens were rent,
torn at last to very rags and tatters, and yet a seamless cope
remained; small imps that fill the air and lay their eggs on the ground
on bare sand or rocks on the tops of hills, where few have found them;
graceful and slender like ripples caught up from the pond, as leaves
are raised by the wind to float in the heavens; such kindredship is in
Nature. The hawk is aerial brother of the wave which he sails over and
surveys, those his perfect air-inflated wings answering to the
elemental unfledged pinions of the sea. Or sometimes I watched a pair
of hen-hawks circling high in the sky, alternately soaring and
descending, approaching, and leaving one another, as if they were the
embodiment of my own thoughts. Or I was attracted by the passage of
wild pigeons from this wood to that, with a slight quivering winnowing
sound and carrier haste; or from under a rotten stump my hoe turned up
a sluggish portentous and outlandish spotted salamander, a trace of
Egypt and the Nile, yet our contemporary. When I paused to lean on my
hoe, these sounds and sights I heard and saw anywhere in the row, a
part of the inexhaustible entertainment which the country offers.

On gala days the town fires its great guns, which echo like popguns to
these woods, and some waifs of martial music occasionally penetrate
thus far. To me, away there in my bean-field at the other end of the
town, the big guns sounded as if a puffball had burst; and when there
was a military turnout of which I was ignorant, I have sometimes had a
vague sense all the day of some sort of itching and disease in the
horizon, as if some eruption would break out there soon, either
scarlatina or canker-rash, until at length some more favorable puff of
wind, making haste over the fields and up the Wayland road, brought me
information of the “trainers.” It seemed by the distant hum as if
somebody’s bees had swarmed, and that the neighbors, according to
Virgil’s advice, by a faint _tintinnabulum_ upon the most sonorous of
their domestic utensils, were endeavoring to call them down into the
hive again. And when the sound died quite away, and the hum had ceased,
and the most favorable breezes told no tale, I knew that they had got
the last drone of them all safely into the Middlesex hive, and that now
their minds were bent on the honey with which it was smeared.

I felt proud to know that the liberties of Massachusetts and of our
fatherland were in such safe keeping; and as I turned to my hoeing
again I was filled with an inexpressible confidence, and pursued my
labor cheerfully with a calm trust in the future.

When there were several bands of musicians, it sounded as if all the
village was a vast bellows, and all the buildings expanded and
collapsed alternately with a din. But sometimes it was a really noble
and inspiring strain that reached these woods, and the trumpet that
sings of fame, and I felt as if I could spit a Mexican with a good
relish,—for why should we always stand for trifles?—and looked round
for a woodchuck or a skunk to exercise my chivalry upon. These martial
strains seemed as far away as Palestine, and reminded me of a march of
crusaders in the horizon, with a slight tantivy and tremulous motion of
the elm-tree tops which overhang the village. This was one of the
_great_ days; though the sky had from my clearing only the same
everlastingly great look that it wears daily, and I saw no difference
in it.

It was a singular experience that long acquaintance which I cultivated
with beans, what with planting, and hoeing, and harvesting, and
threshing, and picking over and selling them,—the last was the hardest
of all,—I might add eating, for I did taste. I was determined to know
beans. When they were growing, I used to hoe from five o’clock in the
morning till noon, and commonly spent the rest of the day about other
affairs. Consider the intimate and curious acquaintance one makes with
various kinds of weeds,—it will bear some iteration in the account, for
there was no little iteration in the labor,—disturbing their delicate
organizations so ruthlessly, and making such invidious distinctions
with his hoe, levelling whole ranks of one species, and sedulously
cultivating another. That’s Roman wormwood,—that’s pigweed,—that’s
sorrel,—that’s piper-grass,—have at him, chop him up, turn his roots
upward to the sun, don’t let him have a fibre in the shade, if you do
he’ll turn himself t’other side up and be as green as a leek in two
days. A long war, not with cranes, but with weeds, those Trojans who
had sun and rain and dews on their side. Daily the beans saw me come to
their rescue armed with a hoe, and thin the ranks of their enemies,
filling up the trenches with weedy dead. Many a lusty crest-waving
Hector, that towered a whole foot above his crowding comrades, fell
before my weapon and rolled in the dust.

Those summer days which some of my contemporaries devoted to the fine
arts in Boston or Rome, and others to contemplation in India, and
others to trade in London or New York, I thus, with the other farmers
of New England, devoted to husbandry. Not that I wanted beans to eat,
for I am by nature a Pythagorean, so far as beans are concerned,
whether they mean porridge or voting, and exchanged them for rice; but,
perchance, as some must work in fields if only for the sake of tropes
and expression, to serve a parable-maker one day. It was on the whole a
rare amusement, which, continued too long, might have become a
dissipation. Though I gave them no manure, and did not hoe them all
once, I hoed them unusually well as far as I went, and was paid for it
in the end, “there being in truth,” as Evelyn says, “no compost or
lætation whatsoever comparable to this continual motion, repastination,
and turning of the mould with the spade.” “The earth,” he adds
elsewhere, “especially if fresh, has a certain magnetism in it, by
which it attracts the salt, power, or virtue (call it either) which
gives it life, and is the logic of all the labor and stir we keep about
it, to sustain us; all dungings and other sordid temperings being but
the vicars succedaneous to this improvement.” Moreover, this being one
of those “worn-out and exhausted lay fields which enjoy their sabbath,”
had perchance, as Sir Kenelm Digby thinks likely, attracted “vital
spirits” from the air. I harvested twelve bushels of beans.

But to be more particular, for it is complained that Mr. Coleman has
reported chiefly the expensive experiments of gentlemen farmers, my
outgoes were,—


    For a hoe,.................................. $ 0.54
    Ploughing, harrowing, and furrowing,.........  7.50  Too much.
    Beans for seed,..............................  3.12½
    Potatoes for seed,...........................  1.33
    Peas for seed,...............................  0.40
    Turnip seed,.................................  0.06
    White line for crow fence,...................  0.02
    Horse cultivator and boy three hours,........  1.00
    Horse and cart to get crop,..................  0.75
                                                ————
        In all,................................. $14.72½

My income was (patrem familias vendacem, non emacem esse oportet),
from

    Nine bushels and twelve quarts of beans sold,. $16.94
    Five    "    large potatoes,.................... 2.50
    Nine    "    small,............................. 2.25
    Grass,.......................................... 1.00
    Stalks,......................................... 0.75
                                                  ————
        In all,................................... $23.44
    Leaving a pecuniary profit,
        as I have elsewhere said, of..............  $8.71½.

This is the result of my experience in raising beans. Plant the common
small white bush bean about the first of June, in rows three feet by
eighteen inches apart, being careful to select fresh round and unmixed
seed. First look out for worms, and supply vacancies by planting anew.
Then look out for woodchucks, if it is an exposed place, for they will
nibble off the earliest tender leaves almost clean as they go; and
again, when the young tendrils make their appearance, they have notice
of it, and will shear them off with both buds and young pods, sitting
erect like a squirrel. But above all harvest as early as possible, if
you would escape frosts and have a fair and salable crop; you may save
much loss by this means.

This further experience also I gained. I said to myself, I will not
plant beans and corn with so much industry another summer, but such
seeds, if the seed is not lost, as sincerity, truth, simplicity, faith,
innocence, and the like, and see if they will not grow in this soil,
even with less toil and manurance, and sustain me, for surely it has
not been exhausted for these crops. Alas! I said this to myself; but
now another summer is gone, and another, and another, and I am obliged
to say to you, Reader, that the seeds which I planted, if indeed they
_were_ the seeds of those virtues, were wormeaten or had lost their
vitality, and so did not come up. Commonly men will only be brave as
their fathers were brave, or timid. This generation is very sure to
plant corn and beans each new year precisely as the Indians did
centuries ago and taught the first settlers to do, as if there were a
fate in it. I saw an old man the other day, to my astonishment, making
the holes with a hoe for the seventieth time at least, and not for
himself to lie down in! But why should not the New Englander try new
adventures, and not lay so much stress on his grain, his potato and
grass crop, and his orchards,—raise other crops than these? Why concern
ourselves so much about our beans for seed, and not be concerned at all
about a new generation of men? We should really be fed and cheered if
when we met a man we were sure to see that some of the qualities which
I have named, which we all prize more than those other productions, but
which are for the most part broadcast and floating in the air, had
taken root and grown in him. Here comes such a subtile and ineffable
quality, for instance, as truth or justice, though the slightest amount
or new variety of it, along the road. Our ambassadors should be
instructed to send home such seeds as these, and Congress help to
distribute them over all the land. We should never stand upon ceremony
with sincerity. We should never cheat and insult and banish one another
by our meanness, if there were present the kernel of worth and
friendliness. We should not meet thus in haste. Most men I do not meet
at all, for they seem not to have time; they are busy about their
beans. We would not deal with a man thus plodding ever, leaning on a
hoe or a spade as a staff between his work, not as a mushroom, but
partially risen out of the earth, something more than erect, like
swallows alighted and walking on the ground:—

     “And as he spake, his wings would now and then
     Spread, as he meant to fly, then close again,”

so that we should suspect that we might be conversing with an angel.
Bread may not always nourish us; but it always does us good, it even
takes stiffness out of our joints, and makes us supple and buoyant,
when we knew not what ailed us, to recognize any generosity in man or
Nature, to share any unmixed and heroic joy.

Ancient poetry and mythology suggest, at least, that husbandry was once
a sacred art; but it is pursued with irreverent haste and heedlessness
by us, our object being to have large farms and large crops merely. We
have no festival, nor procession, nor ceremony, not excepting our
Cattle-shows and so called Thanksgivings, by which the farmer expresses
a sense of the sacredness of his calling, or is reminded of its sacred
origin. It is the premium and the feast which tempt him. He sacrifices
not to Ceres and the Terrestrial Jove, but to the infernal Plutus
rather. By avarice and selfishness, and a grovelling habit, from which
none of us is free, of regarding the soil as property, or the means of
acquiring property chiefly, the landscape is deformed, husbandry is
degraded with us, and the farmer leads the meanest of lives. He knows
Nature but as a robber. Cato says that the profits of agriculture are
particularly pious or just, (_maximeque pius quæstus_), and according
to Varro the old Romans “called the same earth Mother and Ceres, and
thought that they who cultivated it led a pious and useful life, and
that they alone were left of the race of King Saturn.”

We are wont to forget that the sun looks on our cultivated fields and
on the prairies and forests without distinction. They all reflect and
absorb his rays alike, and the former make but a small part of the
glorious picture which he beholds in his daily course. In his view the
earth is all equally cultivated like a garden. Therefore we should
receive the benefit of his light and heat with a corresponding trust
and magnanimity. What though I value the seed of these beans, and
harvest that in the fall of the year? This broad field which I have
looked at so long looks not to me as the principal cultivator, but away
from me to influences more genial to it, which water and make it green.
These beans have results which are not harvested by me. Do they not
grow for woodchucks partly? The ear of wheat (in Latin _spica_,
obsoletely _speca_, from _spe_, hope) should not be the only hope of
the husbandman; its kernel or grain (_granum_ from _gerendo_, bearing)
is not all that it bears. How, then, can our harvest fail? Shall I not
rejoice also at the abundance of the weeds whose seeds are the granary
of the birds? It matters little comparatively whether the fields fill
the farmer’s barns. The true husbandman will cease from anxiety, as the
squirrels manifest no concern whether the woods will bear chestnuts
this year or not, and finish his labor with every day, relinquishing
all claim to the produce of his fields, and sacrificing in his mind not
only his first but his last fruits also.


